@@ -152,12 +152,14 @@ void RoundtripTest::testVCardRoundtrip()
         QVERIFY(outputFile.open(QIODevice::ReadOnly));
 
         const QByteArray outputRefData = outputFile.readAll();
+        if (outputData.size() != outputRefData.size()) {
+            qDebug() << " outputRefData " << outputRefData << endl;
+            qDebug() << " outputData " << outputData;
+        }
         QCOMPARE(outputData.size(), outputRefData.size());
-
         const QList<QByteArray> outputLines = outputData.split('\n');
         const QList<QByteArray> outputRefLines = outputRefData.split('\n');
         QCOMPARE(outputLines.count(), outputRefLines.count());
-
         for (int i = 0; i < outputLines.count(); ++i) {
             const QByteArray actual = outputLines[i];
             const QByteArray expect = outputRefLines[i];
@@ -179,6 +181,10 @@ void RoundtripTest::testVCardRoundtrip()
         QVERIFY(outputFile.open(QIODevice::ReadOnly));
 
         const QByteArray outputRefData = outputFile.readAll();
+        if (outputData.size() != outputRefData.size()) {
+            qDebug() << " outputRefData " << outputRefData << endl;
+            qDebug() << " outputData " << outputData;
+        }
         //QCOMPARE( outputData.size(), outputRefData.size() );
 
         const QList<QByteArray> outputLines = outputData.split('\n');
